
# Slot: generation_date


date and time that the schema was loaded/generated

URI: [meta:generation_date](https://w3id.org/biolink/biolinkml/meta/generation_date)

## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [Datetime](Datetime.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
